@@ -38,9 +38,9 @@ def parse_config(self, filename):
         return options
 
 
-class Ui_MainWindow(QWidget):
+class Ui_MainWindow(QMainWindow):
     def __init__(self):
-        QWidget.__init__(self, None)
+        QMainWindow.__init__(self, None)
         self.resize(800, 480)
         self.setWindowTitle("GnGeo-gui")
         self.setAttribute(Qt.WA_Maemo5StackedWindow)
@@ -83,6 +83,7 @@ class Ui_MainWindow(QWidget):
         AboutTxt = "<img src=/opt/gngeo-gui/neogeo_background.png />" 
         backgroundLabel.setText(AboutTxt)
 	backgroundLabel.setAlignment(Qt.AlignCenter | Qt.AlignLeft)
+      	self.setCentralWidget(backgroundLabel)
 	# Get Gametitles from rompath
 	ListCmd = self.gui_opts["exec_path"] + "/gngeo --scandir=" + self.options["rompath"] 
 	fin,fout = os.popen4(ListCmd)
@@ -121,8 +122,27 @@ class Ui_MainWindow(QWidget):
 	for Game in Games:
         	self.combo.addItem(Game)
 
+	# Define menubar
+	aboutAction = QAction( '&About', self)
+	configAction = QAction( '&Config', self)
+	self.exitAction = QAction( '&Exit after start game', self)
+        aboutAction.triggered.connect(self.slotAbout)
+        configAction.triggered.connect(self.slotConfig)
+	self.exitAction.setCheckable(True)
+
+	if self.gui_opts["exit_after_launch"] == "false":
+            self.exitAction.setChecked(False)
+	else:
+            self.exitAction.setChecked(True)
+
+        menubar = self.menuBar()
+        fileMenu = menubar.addMenu('&MainMenu')
+        fileMenu.addAction(configAction)
+        fileMenu.addAction(self.exitAction)
+        fileMenu.addAction(aboutAction)
+        
         self.startButton = QPushButton("Start",self)
-        self.startButton.setGeometry(QRect(0, 370, 150, 55))
+        self.startButton.setGeometry(QRect(0, 370, 400, 55))
         font = QFont()
         font.setPointSize(24)
         self.startButton.setFont(font)
@@ -130,40 +150,17 @@ class Ui_MainWindow(QWidget):
 		, SIGNAL("clicked()")
 		, self.on_start_clicked)
 
-        self.exitCheckBox = QCheckBox("Exit gui",self)
-        self.exitCheckBox.setGeometry(QRect(150, 370, 190, 55))
+        self.onesmutePushButton = QPushButton("Mute",self)
+	self.onesmutePushButton.setCheckable(True)
+        self.onesmutePushButton.setGeometry(QRect(400, 370, 400, 55))
         font = QFont()
         font.setPointSize(24)
-        self.exitCheckBox.setFont(font)
-	if self.gui_opts["exit_after_launch"] == "false":
-            self.exitCheckBox.setChecked(False)
-	else:
-            self.exitCheckBox.setChecked(True)
-        self.muteCheckBox = QCheckBox("Mute",self)
-        self.muteCheckBox.setGeometry(QRect(340, 370, 170, 55))
-        font = QFont()
-        font.setPointSize(24)
-        self.muteCheckBox.setFont(font)
+        self.onesmutePushButton.setFont(font)
 	if self.options["sound"] == "true":
-            self.muteCheckBox.setChecked(False)
+            self.onesmutePushButton.setChecked(False)
 	else:
-            self.muteCheckBox.setChecked(True)
+            self.onesmutePushButton.setChecked(True)
 
-        self.configButton = QPushButton("Config",self)
-        self.configButton.setGeometry(QRect(510, 370, 150, 55))
-        font = QFont()
-        font.setPointSize(24)
-        self.configButton.setFont(font)
-	QObject.connect(self.configButton
-		, SIGNAL("clicked()")
-		, self.slotConfig)
-
-        self.pushAboutButton = QPushButton("About",self)
-        self.pushAboutButton.setGeometry(QRect(660, 370, 140, 55))
-        self.pushAboutButton.setFont(font)
-	QObject.connect(self.pushAboutButton
-		, SIGNAL("clicked()")
-		, self.slotAbout)
 	self.logMsg = QLabel(self)
       	self.logMsg.setStyleSheet( \
 	"QLabel { background-color: QLinearGradient( x1: 0, y1: 0, x2: 0, y2: 1, \
@@ -173,13 +170,14 @@ class Ui_MainWindow(QWidget):
 	self.logMsg.setGeometry(0, 350, 800, 20)
 
 
+
     def on_start_clicked(self):
 	gameNbr = self.combo.currentIndex()
 	self.gameFile = self.GameFile[gameNbr]
 	global MyTeller
 	global regel
 
-        if self.muteCheckBox.isChecked():
+        if self.onesmutePushButton.isChecked():
                SOUND_OPT=" --no-sound "
         else:  SOUND_OPT=" --sound "
 
@@ -215,7 +213,7 @@ class Ui_MainWindow(QWidget):
 			open(GNGEOGUI_LOG_FILE, 'w').close()
 			break
 
-        if (self.exitCheckBox.isChecked()) and (self.gui_opts["exit_after_launch"] == "false"):
+        if (self.exitAction.isChecked()) and (self.gui_opts["exit_after_launch"] == "false"):
 		try:
 			ConfigFile = open(GNGEOGUI_CFG_FILE,"w")
 		except:
@@ -226,7 +224,7 @@ class Ui_MainWindow(QWidget):
 			ConfigFile.write("exit_after_launch" + " " + "true\n")
 			ConfigFile.close()
 
-        if (not self.exitCheckBox.isChecked()) and (self.gui_opts["exit_after_launch"] == "true"):
+        if (not self.exitAction.isChecked()) and (self.gui_opts["exit_after_launch"] == "true"):
 		try:
 			ConfigFile = open(GNGEOGUI_CFG_FILE,"w")
 		except:
@@ -237,7 +235,8 @@ class Ui_MainWindow(QWidget):
 			ConfigFile.write("exit_after_launch" + " " + "false\n")
 			ConfigFile.close()
 
-        if self.exitCheckBox.isChecked():
+        if self.exitAction.isChecked():
+               time.sleep(5)
                os._exit(0)
 
     def slotAbout(self):
@@ -255,7 +254,7 @@ class AboutWindow(QMainWindow):
         self.setAttribute(Qt.WA_Maemo5StackedWindow)
         self.setAttribute(Qt.WA_DeleteOnClose)
         self.label = QLabel(self)
-        AboutTxt = "<h3>Gngeo-gui 0.0.5-1</h3><p>" \
+        AboutTxt = "<h3>Gngeo-gui 0.0.5-3</h3><p>" \
                    "<img src=/opt/usr/share/icons/hicolor/64x64/apps/gngeo_gui.png /><br>" \
                    "GnGeo-gui is a Graphical User Interface for GnGeo<p> " \
                    "GnGeo emulates the NeoGeo gameconsole from SNK &#174;</p>" \
@@ -276,53 +275,61 @@ class ConfigWindow(QMainWindow):
         font = QFont()
         font.setPointSize(20)
 	#showfps
-        self.showfpsCheckBox = QCheckBox("Showfps",self)
-        self.showfpsCheckBox.setGeometry(QRect(18, 15, 250, 60))
-        self.showfpsCheckBox.setFont(font)
+        self.showfpsPushButton = QPushButton("Showfps",self)
+	self.showfpsPushButton.setCheckable(True)
+        self.showfpsPushButton.setGeometry(QRect(18, 15, 250, 60))
+        self.showfpsPushButton.setFont(font)
 	if self.options["showfps"] == "true":
-            self.showfpsCheckBox.setChecked(True)
+            self.showfpsPushButton.setChecked(True)
 	#fullscreen
-        self.fullscreenCheckBox = QCheckBox("Fullscreen",self)
-        self.fullscreenCheckBox.setGeometry(QRect(273, 15, 250, 60))
-        self.fullscreenCheckBox.setFont(font)
+        self.fullscreenPushButton = QPushButton("Fullscreen",self)
+	self.fullscreenPushButton.setCheckable(True)
+        self.fullscreenPushButton.setGeometry(QRect(273, 15, 250, 60))
+        self.fullscreenPushButton.setFont(font)
 	if self.options["fullscreen"] == "true":
-            self.fullscreenCheckBox.setChecked(True)
+            self.fullscreenPushButton.setChecked(True)
 	#sound
-        self.soundCheckBox = QCheckBox("Sound",self)
-        self.soundCheckBox.setGeometry(QRect(530, 15, 250, 60))
-        self.soundCheckBox.setFont(font)
+        self.soundPushButton = QPushButton("Sound",self)
+	self.soundPushButton.setCheckable(True)
+        self.soundPushButton.setGeometry(QRect(530, 15, 250, 60))
+        self.soundPushButton.setFont(font)
 	if self.options["sound"] == "true":
-            self.soundCheckBox.setChecked(True)
+            self.soundPushButton.setChecked(True)
 	#autoframeskip
-        self.autoframeskipCheckBox = QCheckBox("Autoframeskip",self)
-        self.autoframeskipCheckBox.setGeometry(QRect(18, 85, 250, 60))
-        self.autoframeskipCheckBox.setFont(font)
+        self.autoframePushButton = QPushButton("Autoframeskip",self)
+	self.autoframePushButton.setCheckable(True)
+        self.autoframePushButton.setGeometry(QRect(18, 85, 250, 60))
+        self.autoframePushButton.setFont(font)
 	if self.options["autoframeskip"] == "true":
-            self.autoframeskipCheckBox.setChecked(True)
+            self.autoframePushButton.setChecked(True)
 	#raster
-        self.rasterCheckBox = QCheckBox("Raster",self)
-        self.rasterCheckBox.setGeometry(QRect(273, 85, 250, 60))
-        self.rasterCheckBox.setFont(font)
+        self.rasterPushButton = QPushButton("Raster",self)
+	self.rasterPushButton.setCheckable(True)
+        self.rasterPushButton.setGeometry(QRect(273, 85, 250, 60))
+        self.rasterPushButton.setFont(font)
 	if self.options["raster"] == "true":
-            self.rasterCheckBox.setChecked(True)
+            self.rasterPushButton.setChecked(True)
 	#interpolation
-        self.interpolationCheckBox = QCheckBox("Interpolation",self)
-        self.interpolationCheckBox.setGeometry(QRect(530, 85, 250, 60))
-        self.interpolationCheckBox.setFont(font)
+        self.interpolationPushButton = QPushButton("Interpolation",self)
+	self.interpolationPushButton.setCheckable(True)
+        self.interpolationPushButton.setGeometry(QRect(530, 85, 250, 60))
+        self.interpolationPushButton.setFont(font)
 	if self.options["interpolation"] == "true":
-            self.interpolationCheckBox.setChecked(True)
+            self.interpolationPushButton.setChecked(True)
 	#sleepidle
-        self.sleepidleCheckBox = QCheckBox("Sleepidle",self)
-        self.sleepidleCheckBox.setGeometry(QRect(18, 170, 250, 60))
-        self.sleepidleCheckBox.setFont(font)
+        self.sleepildePushButton = QPushButton("Sleepidle",self)
+	self.sleepildePushButton.setCheckable(True)
+        self.sleepildePushButton.setGeometry(QRect(18, 170, 250, 60))
+        self.sleepildePushButton.setFont(font)
 	if self.options["sleepidle"] == "true":
-            self.sleepidleCheckBox.setChecked(True)
+            self.sleepildePushButton.setChecked(True)
 	#hwsurface
-        self.hwsurfaceCheckBox = QCheckBox("Hwsurface",self)
-        self.hwsurfaceCheckBox.setGeometry(QRect(273, 170, 250, 60))
-        self.hwsurfaceCheckBox.setFont(font)
+        self.hwsurfacePushButton = QPushButton("Hwsurface",self)
+	self.hwsurfacePushButton.setCheckable(True)
+        self.hwsurfacePushButton.setGeometry(QRect(273, 170, 250, 60))
+        self.hwsurfacePushButton.setFont(font)
 	if self.options["hwsurface"] == "true":
-            self.hwsurfaceCheckBox.setChecked(True)
+            self.hwsurfacePushButton.setChecked(True)
 	#joystick
         #self.joystickCheckBox = QCheckBox("Joystick",self)
         #self.joystickCheckBox.setGeometry(QRect(530, 170, 250, 60))
@@ -385,28 +392,28 @@ class ConfigWindow(QMainWindow):
 
 
     def on_save_clicked(self):
-        if self.soundCheckBox.isChecked():
+        if self.soundPushButton.isChecked():
            self.options["sound"] = "true"
         else: self.options["sound"] = "false" 
-        if self.showfpsCheckBox.isChecked():
+        if self.showfpsPushButton.isChecked():
            self.options["showfps"] = "true"
         else: self.options["showfps"] = "false" 
-        if self.fullscreenCheckBox.isChecked():
+        if self.fullscreenPushButton.isChecked():
            self.options["fullscreen"] = "true"
         else: self.options["fullscreen"] = "false" 
-        if self.autoframeskipCheckBox.isChecked():
+        if self.autoframePushButton.isChecked():
            self.options["autoframeskip"] = "true"
         else: self.options["autoframeskip"] = "false" 
-        if self.rasterCheckBox.isChecked():
+        if self.rasterPushButton.isChecked():
            self.options["raster"] = "true"
         else: self.options["raster"] = "false" 
-        if self.interpolationCheckBox.isChecked():
+        if self.interpolationPushButton.isChecked():
            self.options["interpolation"] = "true"
         else: self.options["interpolation"] = "false" 
-        if self.sleepidleCheckBox.isChecked():
+        if self.sleepildePushButton.isChecked():
            self.options["sleepidle"] = "true"
         else: self.options["sleepidle"] = "false" 
-        if self.hwsurfaceCheckBox.isChecked():
+        if self.hwsurfacePushButton.isChecked():
            self.options["hwsurface"] = "true"
         else: self.options["hwsurface"] = "false" 
         #if self.joystickCheckBox.isChecked():
@@ -466,7 +473,9 @@ class ConfigWindow(QMainWindow):
 			for option in self.options:
 				newConfigFile.write(option + " " + self.options[option] + "\n")
 			newConfigFile.close()
-			QMessageBox.critical(self, "success",  "configuration is saved")
+                        os.system('run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications  \
+                        /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint \
+                        string:"Configuration is succesfully saved"')
 
     def listDefaultFirst(self, optVal,List):
 	Position = List.index(self.options[optVal])
